@@ -13,8 +13,9 @@ Provides progress bars and counters which play nice in a TTY console
 
 from enlighten.counter import Counter, StatusBar, SubCounter
 from enlighten._manager import Manager, get_manager
-from enlighten._util import Justify
+from enlighten._util import EnlightenWarning, Justify
 
 
-__version__ = '1.6.0'
-__all__ = ('Counter', 'Justify', 'Manager', 'StatusBar', 'SubCounter', 'get_manager')
+__version__ = '1.6.1'
+__all__ = ('Counter', 'EnlightenWarning', 'Justify', 'Manager',
+           'StatusBar', 'SubCounter', 'get_manager')
