@@ -12,11 +12,12 @@ Provides Counter and SubConter classes
 """
 
 import platform
+import re
 import sys
 import time
 
 from enlighten._basecounter import BaseCounter, PrintableCounter
-from enlighten._util import format_time
+from enlighten._util import EnlightenWarning, format_time, warn_best_level
 
 COUNTER_FMT = u'{desc}{desc_pad}{count:d} {unit}{unit_pad}' + \
               u'[{elapsed}, {rate:.2f}{unit_pad}{unit}/s]{fill}'
@@ -40,6 +41,11 @@ except UnicodeEncodeError:  # pragma: no cover(Non-unicode Terminal)
 except (AttributeError, TypeError):  # pragma: no cover(Non-standard Terminal)
     pass
 
+# Reserved fields
+COUNTER_FIELDS = {'count', 'desc', 'desc_pad', 'elapsed', 'rate', 'unit', 'unit_pad',
+                  'bar', 'eta', 'len_total', 'percentage', 'total', 'fill'}
+RE_SUBCOUNTER_FIELDS = re.compile(r'(?:count|percentage|eta|rate)_\d+')
+
 
 class SubCounter(BaseCounter):
     """
@@ -111,23 +117,25 @@ class SubCounter(BaseCounter):
         """
 
         # Make sure source is a parent or peer
-        if source is self.parent or getattr(source, 'parent', None) is self.parent:
+        if source is not self.parent and getattr(source, 'parent', None) is not self.parent:
+            raise ValueError('source must be parent or peer')
 
-            if self.count + incr < 0 or source.count - incr < 0:
+        # Make sure counts won't go negative
+        if self.count + incr < 0 or source.count - incr < 0:
+            raise ValueError('Invalid increment: %s' % incr)
+
+        # Make sure parent count won't go negative
+        if source is self.parent:
+            if self.parent.count - self.parent.subcount - incr < 0:
                 raise ValueError('Invalid increment: %s' % incr)
 
-            if source is self.parent:
-                if self.parent.count - self.parent.subcount - incr < 0:
-                    raise ValueError('Invalid increment: %s' % incr)
-
-            else:
-                source.count -= incr
-
-            self.count += incr
-            self.parent.update(0, force)
-
+        # Deduct from peer count
         else:
-            raise ValueError('source must be parent or peer')
+            source.count -= incr
+
+        # Increment self and update parent
+        self.count += incr
+        self.parent.update(0, force)
 
 
 class Counter(PrintableCounter):
@@ -391,7 +399,7 @@ class Counter(PrintableCounter):
     # pylint: disable=too-many-arguments
     def __init__(self, **kwargs):
 
-        super(Counter, self).__init__(**kwargs)
+        super(Counter, self).__init__(keywords=kwargs)
 
         # Accept additional_fields for backwards compatibility
         self.fields = kwargs.pop('fields', kwargs.pop('additional_fields', {}))
@@ -502,6 +510,16 @@ class Counter(PrintableCounter):
 
         fields = self.fields.copy()
         fields.update(self._fields)
+
+        # Warn on reserved fields
+        reserved_fields = (set(fields) & COUNTER_FIELDS) | set(
+            match.group() for match in (RE_SUBCOUNTER_FIELDS.match(key) for key in fields) if match
+        )
+        if reserved_fields:
+            warn_best_level('Ignoring reserved fields specified as user-defined fields: %s' %
+                            ', '.join(reserved_fields),
+                            EnlightenWarning)
+
         fields.update({'bar': u'{0}',
                        'count': self.count,
                        'desc': self.desc or u'',
