@@ -11,11 +11,10 @@ Test module for enlighten._counter and enlighten.counter
 
 import time
 
-from enlighten import Counter, Manager
+from enlighten import Counter, EnlightenWarning, Manager
 import enlighten._counter
-from enlighten._manager import NEEDS_UNICODE_HELP
 
-from tests import TestCase, mock, MockManager, MockTTY, MockCounter
+from tests import TestCase, mock, MockManager, MockTTY, MockCounter, PY2, unittest
 
 
 # pylint: disable=missing-docstring, protected-access, too-many-public-methods
@@ -396,15 +395,15 @@ class TestCounter(TestCase):
         blueBarFormat = self.manager.term.blue(barFormat)
         self.assertNotEqual(len(barFormat), len(blueBarFormat))
 
-        ctr = self.manager.counter(stream=self.tty.stdout, total=10, desc='Test',
-                                   unit='ticks', count=10, bar_format=barFormat)
+        ctr = self.manager.counter(total=10, desc='Test', unit='ticks',
+                                   count=10, bar_format=barFormat)
         formatted1 = ctr.format(width=80)
         self.assertEqual(len(formatted1), 80)
         barLen1 = formatted1.count(BLOCK)
 
         offset = len(self.manager.term.blue(''))
-        ctr = self.manager.counter(stream=self.tty.stdout, total=10, desc='Test',
-                                   unit='ticks', count=10, bar_format=blueBarFormat)
+        ctr = self.manager.counter(total=10, desc='Test', unit='ticks',
+                                   count=10, bar_format=blueBarFormat)
         formatted2 = ctr.format(width=80)
         self.assertEqual(len(formatted2), 80 + offset)
         barLen2 = formatted2.count(BLOCK)
@@ -420,15 +419,15 @@ class TestCounter(TestCase):
                     u'[{elapsed}<{eta}, {rate:.2f}{unit_pad}{unit}/s]'
         barFormat = self.manager.term.blue(barFormat)
 
-        ctr = self.manager.counter(stream=self.tty.stdout, total=10, desc='Test',
-                                   unit='ticks', count=10, bar_format=barFormat, offset=0)
+        ctr = self.manager.counter(total=10, desc='Test', unit='ticks',
+                                   count=10, bar_format=barFormat, offset=0)
         formatted1 = ctr.format(width=80)
         self.assertEqual(len(formatted1), 80)
         barLen1 = formatted1.count(BLOCK)
 
         offset = len(self.manager.term.blue(''))
-        ctr = self.manager.counter(stream=self.tty.stdout, total=10, desc='Test',
-                                   unit='ticks', count=10, bar_format=barFormat, offset=offset)
+        ctr = self.manager.counter(total=10, desc='Test', unit='ticks',
+                                   count=10, bar_format=barFormat, offset=offset)
         formatted2 = ctr.format(width=80)
         self.assertEqual(len(formatted2), 80 + offset)
         barLen2 = formatted2.count(BLOCK)
@@ -436,11 +435,11 @@ class TestCounter(TestCase):
         self.assertTrue(barLen2 == barLen1 + offset)
 
         # Test in counter format
-        ctr = self.manager.counter(stream=self.tty.stdout, total=10, count=50, offset=0)
+        ctr = self.manager.counter(total=10, count=50, offset=0)
         formatted = ctr.format(width=80)
         self.assertEqual(len(formatted), 80)
 
-        ctr = self.manager.counter(stream=self.tty.stdout, total=10, count=50, offset=10)
+        ctr = self.manager.counter(total=10, count=50, offset=10)
         formatted = ctr.format(width=80)
         self.assertEqual(len(formatted), 90)
 
@@ -502,8 +501,6 @@ class TestCounter(TestCase):
 
         self.tty.stdout.write(u'X\n')
         value = self.tty.stdread.readline()
-        if NEEDS_UNICODE_HELP:
-            value = value.decode('utf-8')
 
         self.assertRegex(value, r'Test  50%\|' + u'█+[▏▎▍▌▋▊▉]?' +
                          r'[ ]+\|  50/100 \[00:5\d<00:5\d, \d.\d\d ticks/s\]X\n')
@@ -692,7 +689,7 @@ class TestCounter(TestCase):
         """
 
         bar_format = ctr_format = u'{arg1:s} {count:d}'
-        additional_fields = {'arg1': 'hello', 'count': 100000}
+        additional_fields = {'arg1': 'hello'}
 
         ctr = Counter(stream=self.tty.stdout, total=10, count=1, bar_format=bar_format,
                       fields=additional_fields)
@@ -762,3 +759,29 @@ class TestCounter(TestCase):
         ctr_format = u'{fill}HI{fill}'
         ctr = Counter(stream=self.tty.stdout, count=1, counter_format=ctr_format, fill=u'-')
         self.assertEqual(ctr.format(), u'-' * 39 + 'HI' + u'-' * 39)
+
+    @unittest.skipIf(PY2, 'Skip warnings tests in Python 2')
+    def test_reserved_fields(self):
+        """
+        When reserved fields are used, a warning is raised
+        """
+
+        ctr = Counter(stream=self.tty.stdout, total=10, count=1, fields={'elapsed': 'reserved'})
+        with self.assertWarnsRegex(EnlightenWarning, 'Ignoring reserved fields') as warn:
+            ctr.format()
+        self.assertRegex(__file__, warn.filename)
+
+        ctr = Counter(stream=self.tty.stdout, total=10, fields={'elapsed': 'reserved'})
+        with self.assertWarnsRegex(EnlightenWarning, 'Ignoring reserved fields') as warn:
+            ctr.format()
+        self.assertRegex(__file__, warn.filename)
+
+        ctr = Counter(stream=self.tty.stdout, total=10, count=1, elapsed='reserved')
+        with self.assertWarnsRegex(EnlightenWarning, 'Ignoring reserved fields') as warn:
+            ctr.format()
+        self.assertRegex(__file__, warn.filename)
+
+        ctr = Counter(stream=self.tty.stdout, total=10, elapsed='reserved')
+        with self.assertWarns(EnlightenWarning) as warn:
+            ctr.format()
+        self.assertRegex(__file__, warn.filename)
