@@ -372,6 +372,13 @@ class TestManager(TestCase):
 
             self.assertFalse(atexit.register.called)
 
+        # Set max counter lower and make sure scroll_offset hasn't changed
+        manager.counters['dummy'] = 1
+        with mock.patch('enlighten._manager.atexit') as atexit:
+            with mock.patch.object(term, 'change_scroll'):
+                manager._set_scroll_area()
+        self.assertEqual(manager.scroll_offset, 4)
+
     def test_set_scroll_area_height(self):
         manager = _manager.Manager(stream=self.tty.stdout, counter_class=MockCounter)
         manager.counters['dummy'] = 3
@@ -456,7 +463,7 @@ class TestManager(TestCase):
 
             # Clear stream
             self.tty.stdout.write(u'X\n')
-            for num in range(4 + 1):  # pylint: disable=unused-variable
+            for _ in range(4 + 1):
                 self.tty.stdread.readline()
 
             self.assertFalse(reset.called)
@@ -782,7 +789,7 @@ class TestGetManager(TestCase):
             self.assertTrue(manager.defaults['enabled'])
 
     @unittest.skipIf(STDOUT_NO_FD, 'No file descriptor for stdout')
-    def test_get_manager_notty(self):
+    def test_get_manager_no_tty(self):
 
         # stdout is not attached to a tty
         with redirect_output('stdout', OUTPUT):
